@@ -1,6 +1,6 @@
 //! Helpers to introspect Rust code when generating bindings, mostly derived by the `#[ffi_...]` macros.
 
-use crate::lang::c::{CType, Constant, ConstantValue, FnPointerType, Function, FunctionSignature, Parameter, PrimitiveType, PrimitiveValue, Variant};
+use crate::lang::c::{ArrayType, CType, Constant, ConstantValue, FnPointerType, Function, FunctionSignature, Parameter, PrimitiveType, PrimitiveValue, Variant};
 use std::ptr::NonNull;
 
 /// Implemented for a constant-helper produced by [`ffi_constant`](crate::ffi_constant), gives meta info for a constant.
@@ -293,3 +293,12 @@ where
         CType::FnPointer(FnPointerType::new(sig))
     }
 }
+
+unsafe impl<T, const N: usize> CTypeInfo for [T; N]
+where
+    T: CTypeInfo,
+{
+    fn type_info() -> CType {
+        CType::Array(ArrayType::new(T::type_info(), N))
+    }
+}
